Module runner

Module runner 

Functions

aggregate_impact_metrics
confidence_from_str
index_repo
Index a cloned repo into an isolated temp database.
run_impact_scenarios
run_impact_suite
Run the full impact evaluation suite.
run_search_queries
run_search_suite
Run the full search evaluation suite.
validate_ground_truth
Validate that all expected qualified names exist in the indexed graph.