pub fn index_repo(clone_path: &Path) -> Result<(SqliteStore, TempDir)>Expand description
Index a cloned repo into an isolated temp database.
pub fn index_repo(clone_path: &Path) -> Result<(SqliteStore, TempDir)>Index a cloned repo into an isolated temp database.