Functions
- aggregate_
impact_ metrics - confidence_
from_ str - index_
repo - Index a cloned repo into an isolated temp database.
- run_
impact_ scenarios - run_
impact_ suite - Run the full impact evaluation suite.
- run_
search_ queries - run_
search_ suite - Run the full search evaluation suite.
- validate_
ground_ truth - Validate that all expected qualified names exist in the indexed graph.